@@ -1,4 +1,4 @@
-# Copyright 2015-2016 Google Inc. All Rights Reserved.
+# Copyright 2015 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,15 +22,21 @@ from lib2to3 import pytree
 from yapf.yapflib import pytree_utils
 from yapf.yapflib import pytree_visitor
 from yapf.yapflib import split_penalty
+from yapf.yapflib import style
+
+from yapftests import yapf_test_helper
 
 UNBREAKABLE = split_penalty.UNBREAKABLE
 VERY_STRONGLY_CONNECTED = split_penalty.VERY_STRONGLY_CONNECTED
 DOTTED_NAME = split_penalty.DOTTED_NAME
 STRONGLY_CONNECTED = split_penalty.STRONGLY_CONNECTED
-CONTIGUOUS_LIST = split_penalty.CONTIGUOUS_LIST
 
 
-class SplitPenaltyTest(unittest.TestCase):
+class SplitPenaltyTest(yapf_test_helper.YAPFTest):
+
+  @classmethod
+  def setUpClass(cls):
+    style.SetGlobalStyle(style.CreateChromiumStyle())
 
   def _ParseAndComputePenalties(self, code, dumptree=False):
     """Parses the code and computes split penalties.
@@ -62,8 +68,9 @@ class SplitPenaltyTest(unittest.TestCase):
       if pytree_utils.NodeName(tree) in pytree_utils.NONSEMANTIC_TOKENS:
         return []
       if isinstance(tree, pytree.Leaf):
-        return [(tree.value, pytree_utils.GetNodeAnnotation(
-            tree, pytree_utils.Annotation.SPLIT_PENALTY))]
+        return [(tree.value,
+                 pytree_utils.GetNodeAnnotation(
+                     tree, pytree_utils.Annotation.SPLIT_PENALTY))]
       nodes = []
       for node in tree.children:
         nodes += FlattenRec(node)
@@ -132,12 +139,12 @@ class SplitPenaltyTest(unittest.TestCase):
       """)
     tree = self._ParseAndComputePenalties(code)
     self._CheckPenalties(tree, [
-        ('lambda', None),
-        ('a', UNBREAKABLE),
-        (',', UNBREAKABLE),
-        ('b', UNBREAKABLE),
-        (':', UNBREAKABLE),
-        ('None', UNBREAKABLE),
+        ('lambda', VERY_STRONGLY_CONNECTED),
+        ('a', VERY_STRONGLY_CONNECTED),
+        (',', VERY_STRONGLY_CONNECTED),
+        ('b', VERY_STRONGLY_CONNECTED),
+        (':', VERY_STRONGLY_CONNECTED),
+        ('None', VERY_STRONGLY_CONNECTED),
     ])
 
     # Test dotted names.
@@ -173,10 +180,10 @@ class SplitPenaltyTest(unittest.TestCase):
         (',', None),
         ('y', None),
         ('(', UNBREAKABLE),
-        ('lambda', STRONGLY_CONNECTED),
-        ('a', UNBREAKABLE),
-        (':', UNBREAKABLE),
-        ('23', UNBREAKABLE),
+        ('lambda', VERY_STRONGLY_CONNECTED),
+        ('a', VERY_STRONGLY_CONNECTED),
+        (':', VERY_STRONGLY_CONNECTED),
+        ('23', VERY_STRONGLY_CONNECTED),
         (')', VERY_STRONGLY_CONNECTED),
         (':', STRONGLY_CONNECTED),
         ('37', None),
@@ -191,18 +198,18 @@ class SplitPenaltyTest(unittest.TestCase):
     tree = self._ParseAndComputePenalties(code)
     self._CheckPenalties(tree, [
         ('[', None),
-        ('a', STRONGLY_CONNECTED),
-        ('for', STRONGLY_CONNECTED),
+        ('a', None),
+        ('for', 0),
         ('a', STRONGLY_CONNECTED),
         ('in', STRONGLY_CONNECTED),
         ('foo', STRONGLY_CONNECTED),
-        ('if', STRONGLY_CONNECTED),
+        ('if', 0),
         ('a', STRONGLY_CONNECTED),
-        ('.', UNBREAKABLE),
+        ('.', VERY_STRONGLY_CONNECTED),
         ('x', DOTTED_NAME),
         ('==', STRONGLY_CONNECTED),
         ('37', STRONGLY_CONNECTED),
-        (']', STRONGLY_CONNECTED),
+        (']', None),
     ])
 
   def testFuncCalls(self):
@@ -211,11 +218,11 @@ class SplitPenaltyTest(unittest.TestCase):
     self._CheckPenalties(tree, [
         ('foo', None),
         ('(', UNBREAKABLE),
-        ('1', CONTIGUOUS_LIST),
-        (',', CONTIGUOUS_LIST),
-        ('2', CONTIGUOUS_LIST),
-        (',', CONTIGUOUS_LIST),
-        ('3', CONTIGUOUS_LIST),
+        ('1', None),
+        (',', UNBREAKABLE),
+        ('2', None),
+        (',', UNBREAKABLE),
+        ('3', None),
         (')', VERY_STRONGLY_CONNECTED),
     ])
 
@@ -224,16 +231,33 @@ class SplitPenaltyTest(unittest.TestCase):
     tree = self._ParseAndComputePenalties(code)
     self._CheckPenalties(tree, [
         ('foo', None),
-        ('.', UNBREAKABLE),
+        ('.', VERY_STRONGLY_CONNECTED),
         ('bar', DOTTED_NAME),
-        ('.', STRONGLY_CONNECTED),
+        ('.', VERY_STRONGLY_CONNECTED),
         ('baz', DOTTED_NAME),
         ('(', STRONGLY_CONNECTED),
-        ('1', CONTIGUOUS_LIST),
-        (',', CONTIGUOUS_LIST),
-        ('2', CONTIGUOUS_LIST),
-        (',', CONTIGUOUS_LIST),
-        ('3', CONTIGUOUS_LIST),
+        ('1', None),
+        (',', UNBREAKABLE),
+        ('2', None),
+        (',', UNBREAKABLE),
+        ('3', None),
+        (')', VERY_STRONGLY_CONNECTED),
+    ])
+
+    # Test single generator argument.
+    code = 'max(i for i in xrange(10))\n'
+    tree = self._ParseAndComputePenalties(code)
+    self._CheckPenalties(tree, [
+        ('max', None),
+        ('(', UNBREAKABLE),
+        ('i', 0),
+        ('for', 0),
+        ('i', STRONGLY_CONNECTED),
+        ('in', STRONGLY_CONNECTED),
+        ('xrange', STRONGLY_CONNECTED),
+        ('(', UNBREAKABLE),
+        ('10', STRONGLY_CONNECTED),
+        (')', VERY_STRONGLY_CONNECTED),
         (')', VERY_STRONGLY_CONNECTED),
     ])
 
